@@ -16,7 +16,7 @@
 
 import numpy
 import pytest
-from cfelpyutils.geometry import compute_pix_maps, load_crystfel_geometry
+from cfelpyutils.geometry import compute_pix_maps
 from cfelpyutils.peakfinding.peakfinder8 import Peakfinder8PeakDetection
 from tests.fixtures import detector_geometry
 
@@ -82,7 +82,7 @@ class TestPeakfinder8PeakDetection:
     def test_find_peak(self, peakfinder_config, detector_image_with_4_peaks):
         peakfinder = Peakfinder8PeakDetection(**peakfinder_config)
         peak_list = peakfinder.find_peaks(detector_image_with_4_peaks)
-        assert peak_list["num_peaks"] == 4
-        assert len(peak_list["intensity"]) == 4
-        assert len(peak_list["fs"]) == 4
-        assert len(peak_list["ss"]) == 4
+        assert peak_list.num_peaks == 4
+        assert len(peak_list.intensity) == 4
+        assert len(peak_list.fs) == 4
+        assert len(peak_list.ss) == 4
